scan_path_controlled

Function scan_path_controlled 

pub fn scan_path_controlled(
    root: &Path,
    path: &Path,
    options: &ScanOptions,
    limits: ScanLimits,
    control: &IndexWorkControl,
) -> FsResult<Option<Node>>
Scan one path with explicit resource and cooperative-stop controls.

Errors

Returns an error when root canonicalization or metadata reads fail, cancellation or the deadline is observed, or a scan limit is exceeded.