scan_path_with_policy_controlled

Function scan_path_with_policy_controlled 

pub fn scan_path_with_policy_controlled(
    policy: &RootScanPolicy,
    path: &Path,
    limits: ScanLimits,
    control: &IndexWorkControl,
) -> FsResult<Option<Node>>
Scan one path using repository policy already resolved for the selected root.

Errors

Returns an error when path canonicalization or metadata reads fail, cancellation or the deadline is observed, or a scan limit is exceeded.