pub struct RootScanPolicy { /* private fields */ }Expand description
Canonical selected root plus its resolved repository exclusion policy.
Implementations
Sourceimpl RootScanPolicy
impl RootScanPolicy
Sourcepub fn discover(
root: &Path,
options: &ScanOptions,
control: &IndexWorkControl,
) -> FsResult<Self>
pub fn discover( root: &Path, options: &ScanOptions, control: &IndexWorkControl, ) -> FsResult<Self>
Discover bounded repository policy once for one selected scan root.
Errors
Returns an error when the root is invalid, repository boundary metadata cannot be validated, or cooperative work has stopped.