pub struct ScanOptions {
pub exclude_dir_names: Vec<String>,
pub exclude_dir_suffixes: Vec<String>,
pub exclude_path_prefixes: Vec<String>,
pub language_overrides: BTreeMap<String, String>,
pub admit_optional_languages: bool,
}Expand description
Repository scanner configuration.
Fields
exclude_dir_names: Vec<String>Additional directory names to exclude.
exclude_dir_suffixes: Vec<String>Additional directory suffixes to exclude.
exclude_path_prefixes: Vec<String>Repository-relative path prefixes to exclude.
language_overrides: BTreeMap<String, String>Explicit filename or extension selectors mapped to canonical language IDs.
admit_optional_languages: boolWhether registry-known optional languages may be assigned to scanned files.
Implementations
Sourceimpl ScanOptions
impl ScanOptions
Sourcepub fn excludes_relative_path(&self, relative_path: &str) -> bool
pub fn excludes_relative_path(&self, relative_path: &str) -> bool
Return whether a repository-relative slash path is excluded.