pub struct ScanWork {
pub entries: u64,
pub source_bytes: u64,
}Expand description
Resource work completed by one successful repository scan.
Fields
entries: u64Repository entries admitted by the scan budget, including folders.
source_bytes: u64Exact source bytes admitted by the scan budget while hashing files.